Crate eryon_nrt

Crate eryon_nrt 

This crate works to implemet various primitives and utilities supporting the musical aspects of the project.

Outside of fundamental objects, the primary focus of the crate remains to be the Neo-Riemannian Theory (NRT).

Re-exports

pub use super::navigator::TriadNavigator;
pub use super::convert::*;
pub use super::num::*;
pub use super::kinds::*;
pub use super::harmonic_funcs::*;
pub use super::note::*;
pub use super::octave::*;
pub use super::pitch::*;
pub use super::paths::*;

Modules

error
prelude
tonnetz
traits
transform
this module focuses on implementing the motion planning algorithm for finding paths along the surface of the tonnetz.
triad
types
utils

Structs

FactorsIter
An iterator over the variants of Factors
Triad
A triad is a particular chord composed of three notes that satify particular intervallic constrains with each other. Here, the triad materializes the facet of a hyperedge within a cluster of triads persisted in the Tonnetz. The triad is a fundamental entity in the substrate used to represent the headspace of a plant. Each plant relies on these objects to transverse the surface of the tonnetz so that it may gaurantee the completion of a task.
TriadsIter
An iterator over the variants of Triads

Enums

Components
A chord factor describes the position of a note within a triad. The root factor is the first note of the triad, the third factor is the second note of the triad, and the fifth factor is the third note of the triad.
Factors
Auto-generated discriminant enum variants
MusicError
Triads