Components

Enum Components 

#[repr(usize)]
pub enum Components<T = usize> { Root(T), Third(T), Fifth(T), }
A chord factor describes the position of a note within a triad. The root factor is the first note of the triad, the third factor is the second note of the triad, and the fifth factor is the third note of the triad.

Variants



Root(T)



Third(T)



Fifth(T)

Implementations

Source

impl<T> Components<T>

pub const fn is_root(&self) -> bool

Returns true if the enum is Components::Root otherwise false

pub const fn is_third(&self) -> bool

Returns true if the enum is Components::Third otherwise false

pub const fn is_fifth(&self) -> bool

Returns true if the enum is Components::Fifth otherwise false

Source

impl<T> Components<T>

pub fn new(data: T, factor: Factors) -> Self

pub fn factor(&self) -> Factors

Returns the factor of the chord.

pub fn fifth(data: T) -> Self

Initialize a new fifth factor.

pub fn root(data: T) -> Self

Initialize a new root factor.

pub fn third(data: T) -> Self

Initialize a new third factor.