LPR

Enum LPR 

pub enum LPR {
    Leading,
    Parallel,
    Relative,
}
Enumerates primary available transformations in Neo-Riemannian theory.

Each transformation is invertible, meaning that consecutive applications of any transformation will return the original triad. Furthermore, LPR transformations may be chained together in discrete or continuous sequences to create complex harmonic progressions.

The transformations are:

  • Leading (L):
    • [Major] given a major triad, subtract a semitone from the root and move it to the fifth
    • [Minor] given a minor triad, add a semitone to the fifth and move it to the root
  • Parallel (P):
    • [Major] given a major triad, subtract a semitone from the third
    • [Minor] given a minor triad, add a semitone to the third
  • Relative (R):
    • [Major] given a major triad, add a tone to the fifth and move it to the root
    • [Minor] given a minor triad, subtract a tone from the root and move it to the fifth

These transformations can be described categorically as morphisms between various triads. More specifically, they are contravariant functors between categories of triads.

Variants



Leading

Leading (L) transformation



Parallel

Parallel (P) transformation



Relative

Relative (R) transformation

Implementations

Source

impl LPR

pub const fn is_leading(&self) -> bool

Returns true if the enum is LPR::Leading otherwise false

pub const fn is_parallel(&self) -> bool

Returns true if the enum is LPR::Parallel otherwise false

pub const fn is_relative(&self) -> bool

Returns true if the enum is LPR::Relative otherwise false

Source

impl LPR

pub fn leading() -> Self

pub fn parallel() -> Self

pub fn relative() -> Self

pub fn apply(&self, triad: &Triad) -> Triad

pub fn try_apply(&self, triad: &Triad) -> Result<Triad, MusicError>

Apply a transformation to a triad