MotionPlanner

Struct MotionPlanner 

pub struct MotionPlanner<'a> { /* private fields */ }
Motion planning algorithm for finding optimal paths in the Tonnetz

Implementations

Source

impl<'a> MotionPlanner<'a>

pub fn new(tonnetz: &'a Tonnetz) -> Self

Create a new motion planner for the given tonnetz

pub fn set_max_depth(&mut self, depth: usize)

Set the maximum search depth

pub fn set_max_paths(&mut self, paths: usize)

Set the maximum number of paths to find

pub fn with_max_depth(self, depth: usize) -> Self

consumes the current instance to create another with the given maximum depth

pub fn with_max_paths(self, paths: usize) -> Self

consumes the current instance to create another with the given maximum number of paths

pub const fn cache(&self) -> &PathCache

returns an immutable reference to the cache

pub fn cache_mut(&mut self) -> &mut PathCache

returns a mutable reference to the cache

pub fn find_paths_to_pitch( &mut self, start_edge: EdgeId, target_pitch: usize, ) -> Vec<Path>

find a set of paths from one triad to one that contains the target pitch

pub fn find_paths_between_edges( &mut self, start_edge: EdgeId, goal_edge: EdgeId, ) -> Vec<Path>

Search for paths between two specific edges in the tonnetz

pub fn search_from( &self, start_triad: Triad, target_pitch: usize, transforms: Vec<LPR>, triads: Vec<Triad>, edge_ids: Vec<Option<EdgeId>>, max_paths: usize, remaining_depth: usize, ) -> Vec<Path>

Find paths from a specified edge by continuing search from a given state Used for parallel search implementations