Note

Struct Note 

pub struct Note { /* private fields */ }

Implementations

Source

impl Note

pub fn new(class: usize, Octave: Octave) -> Self

pub fn from_pitch(pitch: usize) -> Self

returns a new note from a pitch value

pub const fn class(&self) -> usize

returns a copy to the index of the note’s class

pub fn class_mut(&mut self) -> &mut usize

returns a mutable reference to the index of the note’s class

pub const fn octave(&self) -> Octave

returns a copy to the octave of the note

pub fn octave_mut(&mut self) -> &mut Octave

returns a mutable reference to the current octave

pub fn set_class(&mut self, class: usize)

set the pitch class of the note

pub fn set_octave(&mut self, octave: Octave)

set the octave of the note

pub fn with_class(self, class: usize) -> Self

consumes the current instance to create another with the given pitch class

pub fn with_octave(self, octave: Octave) -> Self

consumes the current instance to create another with the given octave