#[repr(usize)]pub enum Components<T = usize> {
Root(T),
Third(T),
Fifth(T),
}Expand description
A chord factor describes the position of a note within a triad.
The root factor is the first note of the triad, the third factor is the
second note of the triad, and the fifth factor is the third note of the triad.
Variants
Implementations
Sourceimpl<T> Components<T>
impl<T> Components<T>