pub struct Note { /* private fields */ }Implementations
Sourceimpl Note
impl Note
pub fn new(class: usize, Octave: Octave) -> Self
Sourcepub fn from_pitch(pitch: usize) -> Self
pub fn from_pitch(pitch: usize) -> Self
returns a new note from a pitch value
Sourcepub fn class_mut(&mut self) -> &mut usize
pub fn class_mut(&mut self) -> &mut usize
returns a mutable reference to the index of the note’s class
Sourcepub fn octave_mut(&mut self) -> &mut Octave
pub fn octave_mut(&mut self) -> &mut Octave
returns a mutable reference to the current octave
Sourcepub fn set_octave(&mut self, octave: Octave)
pub fn set_octave(&mut self, octave: Octave)
set the octave of the note
Sourcepub fn with_class(self, class: usize) -> Self
pub fn with_class(self, class: usize) -> Self
consumes the current instance to create another with the given pitch class
Sourcepub fn with_octave(self, octave: Octave) -> Self
pub fn with_octave(self, octave: Octave) -> Self
consumes the current instance to create another with the given octave